==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Taggar",
    "Update" : "Uppdatera",
    "Create" : "Skapa",
    "Select tag…" : "Välj tagg...",
    "Tagged files" : "Taggade filer",
    "Select tags to filter by" : "Välj taggar att filtrera med",
    "No tags found" : "Inga taggar hittades",
    "Please select tags to filter by" : "Vänligen välj taggar att filtrera med",
    "No files found for the selected tags" : "Inga filer hittades för de valda taggarna",
    "System tag %1$s added by the system" : "Systemtagg %1$s tillagt av systemet",
    "Added system tag {systemtag}" : "La till systemtagg {systemtag}",
    "Added system tag %1$s" : "La till systemtagg %1$s",
    "%1$s added system tag %2$s" : "%1$s la till systemtagg %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la till systemtagg {systemtag}",
    "System tag %1$s removed by the system" : "Systemtagg %1$s borttagen av systemet",
    "Removed system tag {systemtag}" : "Tog bort systemtagg {systemtag}",
    "Removed system tag %1$s" : "Tog bort systemtagg %1$s",
    "%1$s removed system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You created system tag %1$s" : "Du skapade systemtagg %1$s",
    "You created system tag {systemtag}" : "Du skapade systemtagg {systemtag}",
    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
    "{actor} created system tag {systemtag}" : "{actor} skapade systemtagg {systemtag}",
    "You deleted system tag %1$s" : "Du raderade systemtagg %1$s",
    "You deleted system tag {systemtag}" : "Du raderade systemtagg {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s raderade systemtagg %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} raderade systemtagg {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du uppdaterade systemtagg %2$s till %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systemtagg %2$s adderades till %1$s av systemet",
    "System tag {systemtag} was added to {file} by the system" : "Systemtagg {systemtag} adderades till {file} av systemet",
    "You added system tag %2$s to %1$s" : "Du la till systemtagg %2$s på %1$s",
    "You added system tag {systemtag} to {file}" : "Du la till systemtagg {systemtag} på {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la till systemtagg %3$s på %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la till systemtagg {systemtag} på {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systemtagg %2$s raderades från %1$s av systemet",
    "System tag {systemtag} was removed from {file} by the system" : "Systemtagg {systemtag} raderades från {file} av systemet",
    "You removed system tag %2$s from %1$s" : "Du tog bort systemtagg %2$s från %1$s",
    "You removed system tag {systemtag} from {file}" : "Du tog bort systemtagg {systemtag} från {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s tog bort systemtagg %3$s från %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} tog bort systemtagg {systemtag} från {file}",
    "%s (restricted)" : "%s (begränsad)",
    "%s (invisible)" : "%s (osynlig)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
    "Collaborative tags" : "Samverkande taggar",
    "Collaborative tagging functionality which shares tags among users." : "Samarbetande tagg-funktionalitet som delar taggar bland användare.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbetande tagg-funktionalitet som delar taggar bland användare. Bra för arbetsgrupper.\n\t(Om du är en leverantör med flera kunder, rekommenderas att deaktivera den här appen eftersom taggar delas.)",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbetstaggar är tillgängliga för alla användare. Begränsade taggar är synliga för användarna men kan inte tilldelas av dom. Osynliga taggar är för internt bruk, eftersom användarna inte kan se eller tilldela dom.",
    "Select tag …" : "Välj tagg ...",
    "Create a new tag" : "Skapa en ny tagg",
    "Name" : "Namn",
    "Public" : "Offentlig",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Delete" : "Radera",
    "Reset" : "Återställ",
    "No files in here" : "Inga filer här inne",
    "No entries found in this folder" : "Ingenting hittades i denna mapp",
    "Size" : "Storlek",
    "Modified" : "Modifierad",
    "Create and edit collaborative tags. These tags affect all users." : "Skapa och redigera samverkanstaggar. Dessa taggar påverkar alla användare."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Taggar",
    "Update" : "Uppdatera",
    "Create" : "Skapa",
    "Select tag…" : "Välj tagg...",
    "Tagged files" : "Taggade filer",
    "Select tags to filter by" : "Välj taggar att filtrera med",
    "No tags found" : "Inga taggar hittades",
    "Please select tags to filter by" : "Vänligen välj taggar att filtrera med",
    "No files found for the selected tags" : "Inga filer hittades för de valda taggarna",
    "System tag %1$s added by the system" : "Systemtagg %1$s tillagt av systemet",
    "Added system tag {systemtag}" : "La till systemtagg {systemtag}",
    "Added system tag %1$s" : "La till systemtagg %1$s",
    "%1$s added system tag %2$s" : "%1$s la till systemtagg %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la till systemtagg {systemtag}",
    "System tag %1$s removed by the system" : "Systemtagg %1$s borttagen av systemet",
    "Removed system tag {systemtag}" : "Tog bort systemtagg {systemtag}",
    "Removed system tag %1$s" : "Tog bort systemtagg %1$s",
    "%1$s removed system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You created system tag %1$s" : "Du skapade systemtagg %1$s",
    "You created system tag {systemtag}" : "Du skapade systemtagg {systemtag}",
    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
    "{actor} created system tag {systemtag}" : "{actor} skapade systemtagg {systemtag}",
    "You deleted system tag %1$s" : "Du raderade systemtagg %1$s",
    "You deleted system tag {systemtag}" : "Du raderade systemtagg {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s raderade systemtagg %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} raderade systemtagg {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du uppdaterade systemtagg %2$s till %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systemtagg %2$s adderades till %1$s av systemet",
    "System tag {systemtag} was added to {file} by the system" : "Systemtagg {systemtag} adderades till {file} av systemet",
    "You added system tag %2$s to %1$s" : "Du la till systemtagg %2$s på %1$s",
    "You added system tag {systemtag} to {file}" : "Du la till systemtagg {systemtag} på {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la till systemtagg %3$s på %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la till systemtagg {systemtag} på {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systemtagg %2$s raderades från %1$s av systemet",
    "System tag {systemtag} was removed from {file} by the system" : "Systemtagg {systemtag} raderades från {file} av systemet",
    "You removed system tag %2$s from %1$s" : "Du tog bort systemtagg %2$s från %1$s",
    "You removed system tag {systemtag} from {file}" : "Du tog bort systemtagg {systemtag} från {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s tog bort systemtagg %3$s från %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} tog bort systemtagg {systemtag} från {file}",
    "%s (restricted)" : "%s (begränsad)",
    "%s (invisible)" : "%s (osynlig)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
    "Collaborative tags" : "Samverkande taggar",
    "Collaborative tagging functionality which shares tags among users." : "Samarbetande tagg-funktionalitet som delar taggar bland användare.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbetande tagg-funktionalitet som delar taggar bland användare. Bra för arbetsgrupper.\n\t(Om du är en leverantör med flera kunder, rekommenderas att deaktivera den här appen eftersom taggar delas.)",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbetstaggar är tillgängliga för alla användare. Begränsade taggar är synliga för användarna men kan inte tilldelas av dem. Osynliga taggar är för internt bruk, eftersom användarna inte kan se eller tilldela dem.",
    "Select tag …" : "Välj tagg ...",
    "Create a new tag" : "Skapa en ny tagg",
    "Name" : "Namn",
    "Public" : "Offentlig",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Delete" : "Radera",
    "Reset" : "Återställ",
    "No files in here" : "Inga filer här inne",
    "No entries found in this folder" : "Ingenting hittades i denna mapp",
    "Size" : "Storlek",
    "Modified" : "Modifierad",
    "Create and edit collaborative tags. These tags affect all users." : "Skapa och redigera samverkanstaggar. Dessa taggar påverkar alla användare."
},
"nplurals=2; plural=(n != 1);");
